@@ -2,28 +2,31 @@
 **
 ** This file is part of Qt Creator
 **
-** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
 **
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Contact: Nokia Corporation (info@qt.nokia.com)
 **
-** Commercial Usage
-**
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Commercial License Agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Nokia.
 **
 ** GNU Lesser General Public License Usage
 **
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this file.
+** Please review the following information to ensure the GNU Lesser General
+** Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at http://qt.nokia.com/contact.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights. These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** Other Usage
+**
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
+** If you have questions regarding the use of this file, please contact
+** Nokia at info@qt.nokia.com.
 **
 **************************************************************************/
 
@@ -35,7 +38,7 @@
 
 #include <coreplugin/editormanager/editormanager.h>
 #include <coreplugin/icore.h>
-#include <coreplugin/uniqueidmanager.h>
+#include <coreplugin/actionmanager/actionmanager.h>
 #include <projectexplorer/projectexplorer.h>
 #include <projectexplorer/session.h>
 #include <texteditor/basetexteditor.h>
@@ -149,7 +152,7 @@ void BookmarkDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
     painter->drawText(6, 2 + opt.rect.top() + fm.ascent(), topLeft);
 
     QString topRight = index.data(BookmarkManager::LineNumber).toString();
-    // Check wheter we need to be fancy and paint some background
+    // Check whether we need to be fancy and paint some background
     int fwidth = fm.width(topLeft);
     if (fwidth + lwidth > opt.rect.width()) {
         int left = opt.rect.right() - lwidth;
@@ -201,16 +204,16 @@ void BookmarkDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opti
     painter->restore();
 }
 
-BookmarkView::BookmarkView(QWidget *parent)
-    : QListView(parent)
+BookmarkView::BookmarkView(QWidget *parent)  :
+    QListView(parent),
+    m_bookmarkContext(new BookmarkContext(this)),
+    m_manager(0)
 {
     setWindowTitle(tr("Bookmarks"));
-    setWindowIcon(QIcon(":/bookmarks/images/bookmark.png"));
 
     connect(this, SIGNAL(clicked(const QModelIndex &)),
             this, SLOT(gotoBookmark(const QModelIndex &)));
 
-    m_bookmarkContext = new BookmarkContext(this);
     ICore::instance()->addContextObject(m_bookmarkContext);
 
     setItemDelegate(new BookmarkDelegate(this));
@@ -227,15 +230,24 @@ BookmarkView::~BookmarkView()
 void BookmarkView::contextMenuEvent(QContextMenuEvent *event)
 {
     QMenu menu;
-    QAction *remove = menu.addAction(tr("&Remove Bookmark"));
-    QAction *removeAll = menu.addAction(tr("Remove all Bookmarks"));
+    QAction *moveUp = menu.addAction(tr("Move Up"));
+    QAction *moveDown = menu.addAction(tr("Move Down"));
+    QAction *remove = menu.addAction(tr("&Remove"));
+    QAction *removeAll = menu.addAction(tr("Remove All"));
     m_contextMenuIndex = indexAt(event->pos());
-    if (!m_contextMenuIndex.isValid())
+    if (!m_contextMenuIndex.isValid()) {
+        moveUp->setEnabled(false);
+        moveDown->setEnabled(false);
         remove->setEnabled(false);
+    }
 
     if (model()->rowCount() == 0)
         removeAll->setEnabled(false);
 
+    connect(moveUp, SIGNAL(triggered()),
+            m_manager, SLOT(moveUp()));
+    connect(moveDown, SIGNAL(triggered()),
+            m_manager, SLOT(moveDown()));
     connect(remove, SIGNAL(triggered()),
             this, SLOT(removeFromContextMenu()));
     connect(removeAll, SIGNAL(triggered()),
@@ -251,18 +263,16 @@ void BookmarkView::removeFromContextMenu()
 
 void BookmarkView::removeBookmark(const QModelIndex& index)
 {
-    BookmarkManager *manager = static_cast<BookmarkManager *>(model());
-    Bookmark *bm = manager->bookmarkForIndex(index);
-    manager->removeBookmark(bm);
+    Bookmark *bm = m_manager->bookmarkForIndex(index);
+    m_manager->removeBookmark(bm);
 }
 
 // The perforcemance of this function could be greatly improved.
 //
 void BookmarkView::removeAll()
 {
-    BookmarkManager *manager = static_cast<BookmarkManager *>(model());
-    while (manager->rowCount()) {
-        QModelIndex index = manager->index(0, 0);
+    while (m_manager->rowCount()) {
+        QModelIndex index = m_manager->index(0, 0);
         removeBookmark(index);
     }
 }
@@ -271,6 +281,7 @@ void BookmarkView::setModel(QAbstractItemModel *model)
 {
     BookmarkManager *manager = qobject_cast<BookmarkManager *>(model);
     QTC_ASSERT(manager, return);
+    m_manager = manager;
     QListView::setModel(model);
     setSelectionModel(manager->selectionModel());
     setSelectionMode(QAbstractItemView::SingleSelection);
@@ -279,42 +290,31 @@ void BookmarkView::setModel(QAbstractItemModel *model)
 
 void BookmarkView::gotoBookmark(const QModelIndex &index)
 {
-    BookmarkManager *bm = static_cast<BookmarkManager *>(model());
-    Bookmark *bk = bm->bookmarkForIndex(index);
-    if (!bm->gotoBookmark(bk))
-        bm->removeBookmark(bk);
+    Bookmark *bk = m_manager->bookmarkForIndex(index);
+    if (!m_manager->gotoBookmark(bk))
+        m_manager->removeBookmark(bk);
 }
 
 ////
 // BookmarkContext
 ////
 
-BookmarkContext::BookmarkContext(BookmarkView *widget)
-    : Core::IContext(widget), m_bookmarkView(widget)
+BookmarkContext::BookmarkContext(QWidget *widget)
+    : Core::IContext(widget)
 {
-    m_context << UniqueIDManager::instance()->uniqueIdentifier(Constants::BOOKMARKS_CONTEXT);
-}
-
-QList<int> BookmarkContext::context() const
-{
-    return m_context;
-}
-
-QWidget *BookmarkContext::widget()
-{
-    return m_bookmarkView;
+      setWidget(widget);
+      setContext(Core::Context(Constants::BOOKMARKS_CONTEXT));
 }
 
 ////
 // BookmarkManager
 ////
 
-BookmarkManager::BookmarkManager()
-  : m_bookmarkIcon(QIcon(QLatin1String(":/bookmarks/images/bookmark.png")))
+BookmarkManager::BookmarkManager() :
+    m_bookmarkIcon(QLatin1String(":/bookmarks/images/bookmark.png")),
+    m_selectionModel(new QItemSelectionModel(this, this))
 {
-    m_selectionModel = new QItemSelectionModel(this, this);
-
-    connect(Core::ICore::instance(), SIGNAL(contextChanged(Core::IContext*)),
+    connect(Core::ICore::instance(), SIGNAL(contextChanged(Core::IContext*,Core::Context)),
             this, SLOT(updateActionStatus()));
 
     connect(ProjectExplorerPlugin::instance()->session(), SIGNAL(sessionLoaded()),
@@ -329,7 +329,7 @@ BookmarkManager::~BookmarkManager()
     end = m_bookmarksMap.end();
     for (it = m_bookmarksMap.begin(); it != end; ++it) {
         FileNameBookmarksMap *bookmarks = it.value();
-        qDeleteAll(bookmarks->values());
+        qDeleteAll(*bookmarks);
         delete bookmarks;
     }
 }
@@ -475,7 +475,7 @@ void BookmarkManager::removeBookmark(Bookmark *bookmark)
     saveBookmarks();
 }
 
-Bookmark *BookmarkManager::bookmarkForIndex(QModelIndex index)
+Bookmark *BookmarkManager::bookmarkForIndex(const QModelIndex &index)
 {
     if (!index.isValid() || index.row() >= m_bookmarksList.size())
         return 0;
@@ -483,10 +483,10 @@ Bookmark *BookmarkManager::bookmarkForIndex(QModelIndex index)
 }
 
 
-bool BookmarkManager::gotoBookmark(Bookmark* bookmark)
+bool BookmarkManager::gotoBookmark(Bookmark *bookmark)
 {
     using namespace TextEditor;
-    if (ITextEditor *editor = BaseTextEditor::openEditorAt(bookmark->filePath(), bookmark->lineNumber()))
+    if (ITextEditor *editor = BaseTextEditorWidget::openEditorAt(bookmark->filePath(), bookmark->lineNumber()))
         return (editor->currentLine() == bookmark->lineNumber());
     return false;
 }
@@ -513,7 +513,7 @@ void BookmarkManager::documentPrevNext(bool next)
     int lastLine = -1;
     int prevLine = -1;
     int nextLine = -1;
-    const QList<Bookmark*> marks = m_bookmarksMap.value(fi.path())->values(fi.fileName());
+    const QList<Bookmark *> marks = m_bookmarksMap.value(fi.path())->values(fi.fileName());
     for (int i = 0; i < marks.count(); ++i) {
         int markLine = marks.at(i)->lineNumber();
         if (firstLine == -1 || firstLine > markLine)
@@ -666,7 +666,7 @@ void BookmarkManager::moveDown()
 }
 
 /* Returns the bookmark at the given file and line number, or 0 if no such bookmark exists. */
-Bookmark* BookmarkManager::findBookmark(const QString &path, const QString &fileName, int lineNumber)
+Bookmark *BookmarkManager::findBookmark(const QString &path, const QString &fileName, int lineNumber)
 {
     if (m_bookmarksMap.contains(path)) {
         foreach (Bookmark *bookmark, m_bookmarksMap.value(path)->values(fileName)) {
@@ -763,15 +763,24 @@ void BookmarkManager::loadBookmarks()
 BookmarkViewFactory::BookmarkViewFactory(BookmarkManager *bm)
     : m_manager(bm)
 {
-
 }
 
-QString BookmarkViewFactory::displayName()
+QString BookmarkViewFactory::displayName() const
 {
     return BookmarkView::tr("Bookmarks");
 }
 
-QKeySequence BookmarkViewFactory::activationSequence()
+int BookmarkViewFactory::priority() const
+{
+    return 300;
+}
+
+QString BookmarkViewFactory::id() const
+{
+    return QLatin1String("Bookmarks");
+}
+
+QKeySequence BookmarkViewFactory::activationSequence() const
 {
     return QKeySequence(Qt::ALT + Qt::Key_M);
 }
